Skip to main content

2026 年 11 月 4 日

Managing container deployments (restart, destroy, status, logs)

After containers are deployed, use the available commands to check deployment status, collect logs, manage the container lifecycle (stop/restart/destroy), and so on.

Usage

dux [command] [flags]

Global Flags

  -h, --help      Print help information
  -v, --verbose   Show verbose logs

Available commands for --help

about       Get legal and privacy information about Dux
cg          CLI to deploy and manage Content Gateway containers
eic         CLI to deploy and manage EIC containers
pacreader   CLI to deploy and manage PAC Reader container
seg         CLI to deploy and manage SEG containers
tunnel      CLI to deploy and manage Tunnel containers
version     Get the version of dux
OperationPurposeCommand(s)Container Type
Check statusView deployment status, version, OS, and other key health checkdux status [flags] - get status of single/multiple container deployment
dux <container> status - get status by specifying the container type
Example:
dux cg status - get status of content gateway
dux status -p 10.87.132.110 - get status of a host/hosts by IP
dux status -n 1,2 - get status of a specific host with node-number as listed in the manifest file
CG, SEG, Tunnel, EIC, PAC Reader
Fetch logsDownload log bundle (or docker logs if down)dux logs [flags]
Example:
dux logs -p 1.2.3.4,-p 1.2.3.5 - fetch logs from a single deployment or multiple deployments (comma-separated) by specifying IP in the order as per the manifest
dux logs -n 2 -n 4 - fetch logs from a single deployment or multiple deployments by node-number in the order as per the manifest
dux logs -n 1 -f - continuously view/follow the run logs of container for a specific node/host ip
CG, SEG, Tunnel, EIC, PAC Reader
Stop containersStop containers on target hostsdux stop
dux stop -p 1.2.3.4 - stop the deployment of container by specifying IP in the order as per the manifest
dux stop -n 2 - stop the deployment of container by specifying node number in the order as per the manifest
CG, SEG, Tunnel, EIC, PAC Reader
Restart containersRestart previously stopped containersdux restart [flags]
dux restart -y - restart container and auto-accept all prompts for y/n
CG, SEG, Tunnel, EIC, PAC Reader
Destroy containersStop and remove containers from host(s)dux destroy [flags]
dux destroy -n 4 - destroy the deployment of container by specifying node number in the order as per the manifest
CG, SEG, Tunnel, EIC, PAC Reader
Verbose outputShow detailed logs for any commanddux deploy -vCG, SEG, Tunnel, EIC, PAC Reader
Interactive shellOpen a shell inside a containerdux exec-shell [flags]
Example:
dux exec-shell -n 1
CG, SEG, Tunnel, EIC, PAC Reader
ShowShow system and container diagnostics for Content Gateway hostsdux show disk -n 1,3, dux show cert -p 192.14.84.166, dux show reachabilityCG, SEG, Tunnel, EIC, PAC Reader

Using about command to get legal and privacy information on dux

dux about

Copyright © 2024-2026 Omnissa. All rights reserved. This product is protected by copyright and intellectual property laws in the United States and other countries as well as by international treaties. Its use is subject to the legal terms in place between you and Omnissa.

 • Omnissa's general and offering-specific legal terms for its products and services are available at: https://www.omnissa.com/legal-center/

 • Omnissa's privacy notice for products and services is located at: https://www.omnissa.com/omnissa-products-services-privacy-notice/

 • Omnissa's open-source software notices can be found at: https://www.omnissa.com/open-source-notices/

Commands specific to Tunnel container

dux tunnel init --help

CLI to deploy and manage Tunnel containers

Usage:
 dux tunnel [command]

Available Commands:
 status    Check status of deployment
 deploy    Deploy Tunnel containers
 destroy   Destroy the Tunnel containers on the given hosts
 exec-shell  Open interactive shell with Tunnel container
 init     Create a manifest file for configuring Tunnel container details for deployment and management
 list     List/search sessions, flows, alerts or allowlist from Tunnel container logs
 log-override Override log level in one or more Tunnel containers deployed
 logs     Get logs from the Tunnel containers deployed 
 restart   Restart the Tunnel container on given hosts
 show     Show system and container diagnostics for Tunnel hosts
 status    Get the status of the Tunnel containers deployed
 stop     Stop the Tunnel containers on given hosts

Flags:
 -h, --help   Print help information
 -v, --verbose  Show verbose logs

Check status of deployment

Usage:
  dux tunnel status [flags]

Flags:
  -p, --ip stringArray            Hostname or IP as specified in the manifest for filtering
  -j, --json                      Get status of Tunnel containers in json format
  -l, --label string              Filter hosts by label
  -m, --manifest-file string      Custom manifest file path (default "/opt/omnissa/dux/ts_manifest.yml")
  -n, --node-number stringArray   Node number as listed in manifest for filtering
  -q, --quiet                     Quiet mode: interactive ssh password prompts are disabled

Global Flags:
  -h, --help      Print help information
  -v, --verbose   Show verbose logs

To get status of all deployments, run the command:

dux status

Example

Status of Tunnel containers deployed

1. Host: 192.14.84.166  Node number(n): 1        Version: 23.12.ph4.14   CPU:   6.97%    Memory:  1137.129 MB   Devices: 0 Cascade: off             Status: Running
2. Host: 192.168.99.180 Status: Not Deployed

In this example, one of the deployments is not in Running state. The status of 192.168.99.180 is not deployed.

Override log level in one or more Tunnel containers deployed

To change the log level in Tunnel Container, use the log-override command.

Example

dux log-override -n 1 -l 4 -d 10

Are you sure you want to set log level in the Tunnel containers deployed in the following hosts to "Debug" for 10 mins? 
  ip : 192.14.84.166 node-number : 1 
  Please confirm (y/n): y
  Log-level was succesfully set to "Debug" in Tunnel container on 192.14.84.166

Enhancements to search and list records from Tunnel container logs

The dux list command can be used to search and list sessions, flows, alerts, or allowlist records from Tunnel server container logs. It provides various filtering options to narrow down the results based on user, destination, time range, and so on.

dux list --help
Global Flags:
  -h, --help      Print help information
  -v, --verbose   Show verbose logs

Examples

TaskCommand
List all records (alerts, sessions, and flows)dux tunnel list --all
List allowlist cache along with all records for node number 1dux tunnel list --allowlist-cache -n 1
Filter records by destinationdux tunnel list --dest www.example.com
Filter records by userdux tunnel list --user john
List alerts within a specific time range (RFC-3339 UTC)dux tunnel list --alert --start 2025-03-20T04:00:00Z --end 2025-03-20T05:00:29Z
Search SBAC records for a username or UDIDdux tunnel list --sbac --user john
dux tunnel list --sbac --user 3E546123AB13094FA7856DABDD16F448
Filter SBAC records within a specific time rangedux tunnel list --sbac --user john --start 2025-03-20T04:00:00Z --end 2025-03-20T05:00:29Z

Available commands for show

Usage:
  dux tunnel show [command]

Available Commands:
  cert         Show TLS certificate status for the Tunnel container (applicable for Tunnel only)
  disk         Show root filesystem disk usage of Tunnel hosts
  dns          Show DNS configuration or resolve a hostname from the Tunnel container
  docker       Show Docker statistics for the Tunnel container
  network      Show network interface statistics for Tunnel hosts
  process      Show host load average and top CPU processes
  reachability Check reachability of the Tunnel container to API, Backend, and DNS servers (applicable for Tunnel only)
  report       Fetch vpnreport of a Tunnel container (applicable for Tunnel only)

Flags:
  -p, --ip stringArray            Hostname or IP as specified in the manifest for filtering
  -l, --label string              Filter hosts by label
  -m, --manifest-file string      Custom manifest file path (default "/opt/omnissa/dux/ts_manifest.yml")
  -n, --node-number stringArray   Node number as listed in manifest for filtering

Global Flags:
  -h, --help      Print help information
  -v, --verbose   Show verbose logs

Commands and flags specific to PAC Reader

Use the update command to update the PAC Reader container on a given host with new runtime values.

FlagDescription
-l, --log-levelUpdate log level for PAC Reader container
Example
--log-level 4
[debug=4, info=3, warn=2, error=2, off=0])
-a, --proxy-auth  Update proxy auth for PAC Reader container
-r, --refresh int  Update pac refresh interval in seconds for PAC Reader container

Examples

TaskCommandExample
Update the log level on PAC Reader containerdux pacreader update -l 4Updating log level for PAC Reader container on 192.62.82.52 to level 5
PAC Reader container was successfully restarted on 192.62.82.52
Update the refresh interval on PAC Reader containerdux pacreader update -r 300Updating pac refresh interval for PAC Reader container on 192.62.82.52 to 300 seconds
PAC Reader container was successfully restarted on 192.62.82.52
Update the proxy auth on PAC Reader containerdux pacreader update -a

此页面对您有帮助吗?

对本主题提供反馈

本主题对您有帮助吗?

请勿填写任何个人信息或机密信息。

正在生成链接…